#!/usr/bin/env python
import sys
import libxml2
import libxslt
from optparse import OptionParser
import os
import stylesheets

def main():
    parser = OptionParser()
    parser.set_defaults(stylesheet_dir="stylesheets", output_dir=".")
    parser.add_option("-s", "--stylesheet_dir", dest="stylesheet_dir",
                     help="load stylesheets from DIR", metavar="DIR")
    parser.add_option("-o", "--output_dir", dest="output_dir",
                     help="write output to DIR", metavar="DIR")
    parser.add_option("-v", "--verbose",
                      action="store_true", dest="verbose")

    (options, args) = parser.parse_args()
    if len(args) != 1:
        parser.error("incorrect number of arguments")
    corkd_journal_wines_xml = args[0] 

    if options.verbose:
	print "Input:", corkd_journal_wines_xml
        print "Stylesheets Dir:", options.stylesheet_dir
        print "Output Dir:", options.output_dir

    # Prepare the inputs
    stylesheets.init(options.stylesheet_dir)
    doc = libxml2.parseFile(corkd_journal_wines_xml)

    # Prepare the output 
    try:
        wines_dir = os.path.join(options.output_dir,"Wines") 
	os.mkdir(wines_dir)
    except OSError:
        # If the Wines directory allready exists it throws an error
        # but we should distinguish this from other errors.
	pass

    # Write the index output
    if options.verbose:
        print "Writing Index"
    output_filename = os.path.join(options.output_dir,"wine_journal_by_rating.txt")
    stylesheets.applyAndSaveResult(stylesheets.journal_index_style, doc, output_filename, {'sort_by': '"rating"'})
    output_filename = os.path.join(options.output_dir,"wine_journal_by_name.txt")
    stylesheets.applyAndSaveResult(stylesheets.journal_index_style, doc, output_filename, {'sort_by': '"name"'})
 
    # Create the details pages
    root = doc.children
    for wine in root.xpathEval("wine"):
        try:
	    wine_id = wine.xpathEval("@id")[0].content
	    output_filename = os.path.join(wines_dir,"%s.txt" % wine_id)
	    if options.verbose:
		print "Writing Wine Details", wine_id
	    stylesheets.applyAndSaveResult(stylesheets.wine_style, doc, output_filename, {'wine_id': '"%s"' % wine_id})
	except Exception, e:
	    print e

    # Cleanup
    stylesheets.free()
    doc.freeDoc()
		
if __name__ == "__main__":
    main()
